==> haskell-data-serializer-0.3-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-8YGiN08hPv538Vggesnlf4
key: data-serializer-0.3-8YGiN08hPv538Vggesnlf4
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Serializer Data.Deserializer
abi: 58e48bdd60b3c55859fd01b5f671a7c6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-serializer-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-8YGiN08hPv538Vggesnlf4
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw
    data-endian-0.1.1-HoeJiLebjQqITdqdHm1S1Z
    parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-jt6Ws2usKC5IVLO6EeEbe
key: data-serializer-0.3-jt6Ws2usKC5IVLO6EeEbe
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Serializer Data.Deserializer
abi: 7d85d1103bfbaf8f7a41c859ff29b45f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-serializer-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-jt6Ws2usKC5IVLO6EeEbe
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw
    data-endian-0.1.1-HoeJiLebjQqITdqdHm1S1Z
    parsers-0.12.6-G0uu9qoRLz4HnH45wJLDZZ
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
